==> refcodes-filesystem-1.1.3-sources.jar: org/refcodes/filesystem/FileSystemRuntimeException.java <==
// /////////////////////////////////////////////////////////////////////////////
// REFCODES.ORG
// =============================================================================
// This code is copyright (c) by Siegfried Steiner, Munich, Germany and licensed
// under the following (see "http://en.wikipedia.org/wiki/Multi-licensing")
// licenses:
// =============================================================================
// GNU General Public License, v3.0 ("http://www.gnu.org/licenses/gpl-3.0.html")
// together with the GPL linking exception applied; as being applied by the GNU
// Classpath ("http://www.gnu.org/software/classpath/license.html")
// =============================================================================
// Apache License, v2.0 ("http://www.apache.org/licenses/LICENSE-2.0")
// =============================================================================
// Please contact the copyright holding author(s) of the software artifacts in
// question for licensing issues not being covered by the above listed licenses,
// also regarding commercial licensing models or regarding the compatibility
// with other open source licenses.
// /////////////////////////////////////////////////////////////////////////////

package org.refcodes.filesystem;

import org.refcodes.exception.AbstractRuntimeException;

public abstract class FileSystemRuntimeException extends AbstractRuntimeException {

	private static final long serialVersionUID = 1L;

	public FileSystemRuntimeException( String aMessage, String aErrorCode ) {
		super( aMessage, aErrorCode );
	}

	public FileSystemRuntimeException( String aMessage, Throwable aCause, String aErrorCode ) {
		super( aMessage, aCause, aErrorCode );
	}

	public FileSystemRuntimeException( String message, Throwable cause ) {
		super( message, cause );
	}

	public FileSystemRuntimeException( String message ) {
		super( message );
	}

	public FileSystemRuntimeException( Throwable aCause, String aErrorCode ) {
		super( aCause, aErrorCode );
	}

	public FileSystemRuntimeException( Throwable cause ) {
		super( cause );
	}

	static abstract class FileSystemFileRuntimeException extends FileSystemRuntimeException implements FileHandleAccessor {

		private static final long serialVersionUID = 1L;

		private FileHandle _file;


		public FileSystemFileRuntimeException( FileHandle aFile, String aMessage, String aErrorCode ) {
			super( aMessage, aErrorCode );
			_file = aFile;
		}


		public FileSystemFileRuntimeException( FileHandle aFile, String aMessage, Throwable aCause, String aErrorCode ) {
			super( aMessage, aCause, aErrorCode );
			_file = aFile;
		}


		public FileSystemFileRuntimeException( FileHandle aFile, String message, Throwable cause ) {
			super( message, cause );
			_file = aFile;
		}


		public FileSystemFileRuntimeException( FileHandle aFile, String message ) {
			super( message );
			_file = aFile;
		}


		public FileSystemFileRuntimeException( FileHandle aFile, Throwable aCause, String aErrorCode ) {
			super( aCause, aErrorCode );
			_file = aFile;
		}


		public FileSystemFileRuntimeException( FileHandle aFile, Throwable cause ) {
			super( cause );
			_file = aFile;
		}

		@Override
		public FileHandle getFile() {
			return _file;
		}
	}
}

==> refcodes-filesystem-1.10.0-sources.jar: org/refcodes/filesystem/FileSystemRuntimeException.java <==
// /////////////////////////////////////////////////////////////////////////////
// REFCODES.ORG
// =============================================================================
// This code is copyright (c) by Siegfried Steiner, Munich, Germany and licensed
// under the following (see "http://en.wikipedia.org/wiki/Multi-licensing")
// licenses:
// =============================================================================
// GNU General Public License, v3.0 ("http://www.gnu.org/licenses/gpl-3.0.html")
// together with the GPL linking exception applied; as being applied by the GNU
// Classpath ("http://www.gnu.org/software/classpath/license.html")
// =============================================================================
// Apache License, v2.0 ("http://www.apache.org/licenses/LICENSE-2.0")
// =============================================================================
// Please contact the copyright holding author(s) of the software artifacts in
// question for licensing issues not being covered by the above listed licenses,
// also regarding commercial licensing models or regarding the compatibility
// with other open source licenses.
// /////////////////////////////////////////////////////////////////////////////

package org.refcodes.filesystem;

import org.refcodes.exception.AbstractRuntimeException;

/**
 * The Class FileSystemRuntimeException.
 */
public abstract class FileSystemRuntimeException extends AbstractRuntimeException {

	private static final long serialVersionUID = 1L;

	/**
	 * Instantiates a new file system runtime exception.
	 *
	 * @param aMessage the message
	 * @param aErrorCode the error code
	 */
	public FileSystemRuntimeException( String aMessage, String aErrorCode ) {
		super( aMessage, aErrorCode );
	}

	/**
	 * Instantiates a new file system runtime exception.
	 *
	 * @param aMessage the message
	 * @param aCause the cause
	 * @param aErrorCode the error code
	 */
	public FileSystemRuntimeException( String aMessage, Throwable aCause, String aErrorCode ) {
		super( aMessage, aCause, aErrorCode );
	}

	/**
	 * Instantiates a new file system runtime exception.
	 *
	 * @param message the message
	 * @param cause the cause
	 */
	public FileSystemRuntimeException( String message, Throwable cause ) {
		super( message, cause );
	}

	/**
	 * Instantiates a new file system runtime exception.
	 *
	 * @param message the message
	 */
	public FileSystemRuntimeException( String message ) {
		super( message );
	}

	/**
	 * Instantiates a new file system runtime exception.
	 *
	 * @param aCause the cause
	 * @param aErrorCode the error code
	 */
	public FileSystemRuntimeException( Throwable aCause, String aErrorCode ) {
		super( aCause, aErrorCode );
	}

	/**
	 * Instantiates a new file system runtime exception.
	 *
	 * @param cause the cause
	 */
	public FileSystemRuntimeException( Throwable cause ) {
		super( cause );
	}

	/**
	 * The Class FileSystemFileRuntimeException.
	 */
	static abstract class FileSystemFileRuntimeException extends FileSystemRuntimeException implements FileHandleAccessor {

		private static final long serialVersionUID = 1L;

		private FileHandle _file;

		/**
		 * Instantiates a new file system file runtime exception.
		 *
		 * @param aFile the file
		 * @param aMessage the message
		 * @param aErrorCode the error code
		 */
		public FileSystemFileRuntimeException( FileHandle aFile, String aMessage, String aErrorCode ) {
			super( aMessage, aErrorCode );
			_file = aFile;
		}

		/**
		 * Instantiates a new file system file runtime exception.
		 *
		 * @param aFile the file
		 * @param aMessage the message
		 * @param aCause the cause
		 * @param aErrorCode the error code
		 */
		public FileSystemFileRuntimeException( FileHandle aFile, String aMessage, Throwable aCause, String aErrorCode ) {
			super( aMessage, aCause, aErrorCode );
			_file = aFile;
		}

		/**
		 * Instantiates a new file system file runtime exception.
		 *
		 * @param aFile the file
		 * @param message the message
		 * @param cause the cause
		 */
		public FileSystemFileRuntimeException( FileHandle aFile, String message, Throwable cause ) {
			super( message, cause );
			_file = aFile;
		}

		/**
		 * Instantiates a new file system file runtime exception.
		 *
		 * @param aFile the file
		 * @param message the message
		 */
		public FileSystemFileRuntimeException( FileHandle aFile, String message ) {
			super( message );
			_file = aFile;
		}

		/**
		 * Instantiates a new file system file runtime exception.
		 *
		 * @param aFile the file
		 * @param aCause the cause
		 * @param aErrorCode the error code
		 */
		public FileSystemFileRuntimeException( FileHandle aFile, Throwable aCause, String aErrorCode ) {
			super( aCause, aErrorCode );
			_file = aFile;
		}

		/**
		 * Instantiates a new file system file runtime exception.
		 *
		 * @param aFile the file
		 * @param cause the cause
		 */
		public FileSystemFileRuntimeException( FileHandle aFile, Throwable cause ) {
			super( cause );
			_file = aFile;
		}

		/**
		 * Gets the file.
		 *
		 * @return the file
		 */
		@Override
		public FileHandle getFile() {
			return _file;
		}
	}
}
